/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Client module: IO Types
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: iotypes.h,v 1.6 2004/11/03 16:17:35 badino Exp $
 *  Release: $Name: glite-data-io-client_R_1_5_2 $
 *
 */

#ifndef GLITE_DATA_IO_CLIENT_IOTYPES_H_
#define GLITE_DATA_IO_CLIENT_IOTYPES_H_

#include <time.h>

/**
 * Primitive Types 
 * TODO Be platform & architecture indipendent 
 */
typedef int       glite_int32;
typedef long long glite_int64; 
typedef void *    glite_handle;
typedef int       glite_result;
typedef time_t    glite_time_t;

#define GLITE_NULL_HANDLE   0

#define GLITE_LFN_LENGTH    1024
#define GLITE_SURL_LENGTH   2048
#define GLITE_GUID_LENGTH   37
#define GLITE_NAME_LENGTH   1024

/**
 * IO Stat Type
 * this structure is used to return File information using the glite_fstat 
 * method. The meaning of each field is the same as the posix stat64 structure, 
 * which extends addition the guid, lfn, surl, owner and group fields
 */
struct glite_stat {
    /**
     * The device
     */
    glite_int32  dev;
    /**
     * The inode on the remote Storage System
     */
    glite_int64  ino;
    /**
     * The file protection and type bits.
     */
    glite_int32  mode;
    /**
     * The number of hard links on the remote Storage System
     */
    glite_int32  nlink;
    /**
     * The user ID of owner on the remote Storage System
     */
    glite_int32  uid;
    /**
     * The group ID of owner on the remote Storage System
     */
    glite_int32  gid;
    /**
     * The device type (if inode device)
     */
    glite_int32  rdev;
    /**
     * The total size, in bytes
     */
    glite_int64  size;
    /**
     * The blocksize for remote Storage Element filesystem I/O
     */
    glite_int32  blksize;
    /**
     * The number of blocks allocated on the remote Storage System
     */
    glite_int64  blocks;
    /**
     * Time of last access
     */
    glite_time_t atime;
    /**
     * Time of last modification
     */
    glite_time_t mtime;
    /**
     * Time of last change
     */
    glite_time_t ctime;
    /**
     * File GUID
     */
    char guid[GLITE_GUID_LENGTH];
    /**
     * The logical file name
     */
    char lfn[GLITE_LFN_LENGTH];
    /**
     * The physical file name
     */
    char surl[GLITE_SURL_LENGTH];
    /**
     * The name of the owner
     */
    char owner[GLITE_NAME_LENGTH];
    /**
     * The group name of owner
     */
    char group[GLITE_NAME_LENGTH];
};

#endif //GLITE_DATA_IO_CLIENT_IOTYPES_H_
